#!/usr/bin/env python
import os
import lagrange
data = """\
### begin data
{'area_adjacency': [[1, 1, 1], [1, 1, 1], [1, 1, 1]],
 'area_dispersal': [[[1.0, 1.0, 1.0], [1.0, 1.0, 1.0], [1.0, 1.0, 1.0]]],
 'area_labels': ['A', 'E', 'NA'],
 'base_rates': '__estimate__',
 'dispersal_durations': [100.7],
 'dm_symmetric_entry': True,
 'excluded_ranges': [],
 'lagrange_version': '20130526',
 'max_range_size': 2,
 'model_name': 'ceratopsian_aba',
 'newick_trees': [{'included': '__all__',
                   'name': 'Tree0',
                   'newick': '(((((((((((((((Centrosaurus:3.1, Diabloceratops:0.1)N2:0.1, (Chasmosaurus:0.1, Triceratops:7.9)N5:3.1)N6:12.6, Turanoceratops:0.1)N8:0.1, Zuniceratops:0.1)N10:0.1, ((Bagaceratops:7.2, Ajkaceratops:0.1)N13:0.1, Protoceratops:10.9)N15:6.4)N16:0.9, Graciliceratops:0.1)N18:6.4, ((((((Zhuchengceratops:13.3, (Unescoceratops:8.7, Gryphoceratops:0.1)N22:0.1)N23:0.1, (Leptoceratops:6.3, Udanoceratops:0.1)N26:10.3)N27:0.1, Prenoceratops:9.5)N29:0.1, Montanaceratops:14.7)N31:0.1, Cerasinops:6.2)N33:14.1, Asiaceratops:0.1)N35:0.1)N36:9.7, Koreaceratops:0.1)N38:0.1, (Helioceratops:3.9, Archaeoceratops:0.1)N41:1.4)N42:0.1, (Auroraceratops:0.1, Yamaceratops:27.6)N45:1.4)N46:0.1, Aquilops:1.8)N48:18.4, Liaoceratops:0.1)N50:2.3, (Psittaco_sinen:0.1, Psittaco_mongol:15.2)N53:0.1)N54:38.8, (Xuanhuaceratops:18.5, Chaoyangsaurus:0.1)N57:0.1)N58:0.1, Yinlong:6.9)N60;',
                   'root_age': 100.7}],
 'ranges': [(), (0,), (0, 1), (0, 2), (1,), (1, 2), (2,)],
 'taxa': ['Ajkaceratops',
          'Aquilops',
          'Archaeoceratops',
          'Asiaceratops',
          'Auroraceratops',
          'Bagaceratops',
          'Centrosaurus',
          'Cerasinops',
          'Chaoyangsaurus',
          'Chasmosaurus',
          'Diabloceratops',
          'Graciliceratops',
          'Gryphoceratops',
          'Helioceratops',
          'Koreaceratops',
          'Leptoceratops',
          'Liaoceratops',
          'Montanaceratops',
          'Prenoceratops',
          'Protoceratops',
          'Psittaco_mongol',
          'Psittaco_sinen',
          'Triceratops',
          'Turanoceratops',
          'Udanoceratops',
          'Unescoceratops',
          'Xuanhuaceratops',
          'Yamaceratops',
          'Yinlong',
          'Zhuchengceratops',
          'Zuniceratops'],
 'taxon_range_data': {'Ajkaceratops': (1,),
                      'Aquilops': (2,),
                      'Archaeoceratops': (0,),
                      'Asiaceratops': (0,),
                      'Auroraceratops': (0,),
                      'Bagaceratops': (0,),
                      'Centrosaurus': (2,),
                      'Cerasinops': (2,),
                      'Chaoyangsaurus': (0,),
                      'Chasmosaurus': (2,),
                      'Diabloceratops': (2,),
                      'Graciliceratops': (0,),
                      'Gryphoceratops': (2,),
                      'Helioceratops': (0,),
                      'Koreaceratops': (0,),
                      'Leptoceratops': (2,),
                      'Liaoceratops': (0,),
                      'Montanaceratops': (2,),
                      'Prenoceratops': (2,),
                      'Protoceratops': (0,),
                      'Psittaco_mongol': (0,),
                      'Psittaco_sinen': (0,),
                      'Triceratops': (2,),
                      'Turanoceratops': (0,),
                      'Udanoceratops': (0,),
                      'Unescoceratops': (2,),
                      'Xuanhuaceratops': (0,),
                      'Yamaceratops': (0,),
                      'Yinlong': (0,),
                      'Zhuchengceratops': (0,),
                      'Zuniceratops': (2,)}}
### end data
"""

i = 0
while 1:
    if not i:
        outfname = "ceratopsian_aba.results.txt"
    else:
        outfname = "ceratopsian_aba.results-"+str(i)+".txt"
    if not os.path.exists(outfname): break
    i += 1
outfile = open(outfname, "w")
lagrange.output.log(lagrange.msg, outfile, tee=True)
model, tree, data, nodelabels, base_rates = lagrange.input.eval_decmodel(data)
lagrange.output.ascii_tree(outfile, tree, model, data, tee=True)
if base_rates != "__estimate__":
    d, e = base_rates
else:
    d, e = lagrange.output.optimize_dispersal_extinction(outfile, tree, model, tee=True)
if nodelabels:
    if nodelabels == "__all__":
        nodelabels = None
    lagrange.output.ancsplits(outfile, tree, model, d, e, nodelabels=nodelabels, tee=True)
