#!/usr/bin/env python
import os
import lagrange
data = """\
### begin data
{'area_adjacency': [[1, 1, 1], [1, 1, 1], [1, 1, 1]],
 'area_dispersal': [[[1.0, 1.0, 1.0], [1.0, 1.0, 1.0], [1.0, 1.0, 1.0]]],
 'area_labels': ['A', 'E', 'NA'],
 'base_rates': '__estimate__',
 'dispersal_durations': [99.3],
 'dm_symmetric_entry': True,
 'excluded_ranges': [],
 'lagrange_version': '20130526',
 'max_range_size': 2,
 'model_name': 'ceratopsian_equal',
 'newick_trees': [{'included': '__all__',
                   'name': 'Tree0',
                   'newick': '(((((((((((((((Centrosaurus:6.125, Diabloceratops:3.125)N2:3.125, (Chasmosaurus:1.5, Triceratops:9.3)N5:7.75)N6:6.35, Turanoceratops:0.1)N8:0.1, Zuniceratops:0.2)N10:0.2, ((Bagaceratops:8.675, Ajkaceratops:1.575)N13:1.575, Protoceratops:13.95)N15:3.55)N16:3.55, Graciliceratops:3.15)N18:7.95, ((((((Zhuchengceratops:13.6375, (Unescoceratops:8.81875, Gryphoceratops:0.21875)N22:0.21875)N23:0.4375, (Leptoceratops:11.3, Udanoceratops:5.1)N26:5.975)N27:0.875, Prenoceratops:11.15)N29:1.75, Montanaceratops:18.1)N31:3.5, Cerasinops:13.1)N33:9.4, Asiaceratops:2.4)N35:2.4)N36:5.94375, Koreaceratops:1.14375)N38:1.14375, (Helioceratops:4.45, Archaeoceratops:0.65)N41:2.9375)N42:2.2875, (Auroraceratops:0.65, Yamaceratops:28.15)N45:5.225)N46:4.575, Aquilops:10.85)N48:10.25, Liaoceratops:1.1)N50:20.45, (Psittaco_sinen:9.675, Psittaco_mongol:24.775)N53:9.675)N54:19.4, (Xuanhuaceratops:18.425, Chaoyangsaurus:0.025)N57:0.025)N58:0.05, Yinlong:6.9)N60;',
                   'root_age': 99.3}],
 'ranges': [(), (0,), (0, 1), (0, 2), (1,), (1, 2), (2,)],
 'taxa': ['Ajkaceratops',
          'Aquilops',
          'Archaeoceratops',
          'Asiaceratops',
          'Auroraceratops',
          'Bagaceratops',
          'Centrosaurus',
          'Cerasinops',
          'Chaoyangsaurus',
          'Chasmosaurus',
          'Diabloceratops',
          'Graciliceratops',
          'Gryphoceratops',
          'Helioceratops',
          'Koreaceratops',
          'Leptoceratops',
          'Liaoceratops',
          'Montanaceratops',
          'Prenoceratops',
          'Protoceratops',
          'Psittaco_mongol',
          'Psittaco_sinen',
          'Triceratops',
          'Turanoceratops',
          'Udanoceratops',
          'Unescoceratops',
          'Xuanhuaceratops',
          'Yamaceratops',
          'Yinlong',
          'Zhuchengceratops',
          'Zuniceratops'],
 'taxon_range_data': {'Ajkaceratops': (1,),
                      'Aquilops': (2,),
                      'Archaeoceratops': (0,),
                      'Asiaceratops': (0,),
                      'Auroraceratops': (0,),
                      'Bagaceratops': (0,),
                      'Centrosaurus': (2,),
                      'Cerasinops': (2,),
                      'Chaoyangsaurus': (0,),
                      'Chasmosaurus': (2,),
                      'Diabloceratops': (2,),
                      'Graciliceratops': (0,),
                      'Gryphoceratops': (2,),
                      'Helioceratops': (0,),
                      'Koreaceratops': (0,),
                      'Leptoceratops': (2,),
                      'Liaoceratops': (0,),
                      'Montanaceratops': (2,),
                      'Prenoceratops': (2,),
                      'Protoceratops': (0,),
                      'Psittaco_mongol': (0,),
                      'Psittaco_sinen': (0,),
                      'Triceratops': (2,),
                      'Turanoceratops': (0,),
                      'Udanoceratops': (0,),
                      'Unescoceratops': (2,),
                      'Xuanhuaceratops': (0,),
                      'Yamaceratops': (0,),
                      'Yinlong': (0,),
                      'Zhuchengceratops': (0,),
                      'Zuniceratops': (2,)}}
### end data
"""

i = 0
while 1:
    if not i:
        outfname = "ceratopsian_equal.results.txt"
    else:
        outfname = "ceratopsian_equal.results-"+str(i)+".txt"
    if not os.path.exists(outfname): break
    i += 1
outfile = open(outfname, "w")
lagrange.output.log(lagrange.msg, outfile, tee=True)
model, tree, data, nodelabels, base_rates = lagrange.input.eval_decmodel(data)
lagrange.output.ascii_tree(outfile, tree, model, data, tee=True)
if base_rates != "__estimate__":
    d, e = base_rates
else:
    d, e = lagrange.output.optimize_dispersal_extinction(outfile, tree, model, tee=True)
if nodelabels:
    if nodelabels == "__all__":
        nodelabels = None
    lagrange.output.ancsplits(outfile, tree, model, d, e, nodelabels=nodelabels, tee=True)
